/**
 *@file tls_config.h
 *@brief CycloneSSL configuration file
 *
 * @section License
 *
 * Copyright (C) 2010-2013 Oryx Embedded. All rights reserved.
 *
 * This file is part of CycloneTCP Open.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded (www.oryx-embedded.com)
 * @version 1.24
 **/

#ifndef _TLS_CONFIG_H
#define _TLS_CONFIG_H

//Trace level for debugging purposes
#define TLS_TRACE_LEVEL 5

//Minimum version that can be negotiated
#define TLS_MIN_VERSION SSL_VERSION_3_0

//Maximum version that can be negotiated
#define TLS_MAX_VERSION TLS_VERSION_1_2

//TLS buffer size
#define TLS_BUFFER_SIZE 16384

//RSA key exchange support
#define TLS_RSA_KEY_EXCH_SUPPORT ENABLED

//DHE_DSS key exchange support
#define TLS_DHE_DSS_KEY_EXCH_SUPPORT DISABLED

//DHE_RSA key exchange support
#define TLS_DHE_RSA_KEY_EXCH_SUPPORT DISABLED

//DH_ANON key exchange support
#define TLS_DH_ANON_KEY_EXCH_SUPPORT DISABLED

//Stream cipher support
#define TLS_STREAM_CIPHER_SUPPORT ENABLED

//CBC block cipher support
#define TLS_CBC_CIPHER_SUPPORT ENABLED

//Galois counter mode support
#define TLS_GCM_CIPHER_SUPPORT DISABLED

//RC4 cipher support
#define TLS_RC4_SUPPORT ENABLED

//IDEA cipher support
#define TLS_IDEA_SUPPORT ENABLED

//DES cipher support
#define TLS_DES_SUPPORT ENABLED

//Triple DES cipher support
#define TLS_3DES_SUPPORT ENABLED

//AES cipher support
#define TLS_AES_SUPPORT ENABLED

//Camellia cipher support
#define TLS_CAMELLIA_SUPPORT ENABLED

//SEED cipher support
#define TLS_SEED_SUPPORT ENABLED

//ARIA cipher support
#define TLS_ARIA_SUPPORT ENABLED

//MD5 hash support
#define TLS_MD5_SUPPORT ENABLED

//SHA-1 hash support
#define TLS_SHA1_SUPPORT ENABLED

//SHA-256 hash support
#define TLS_SHA256_SUPPORT ENABLED

//SHA-384 hash support
#define TLS_SHA384_SUPPORT ENABLED

#endif
